==> nextcloud-27.1.2.tgz: nextcloud/apps/serverinfo/l10n/ru.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Информация о ЦП недоступна",
    "Load average: {cpu} (last minute)" : "Загрузка процессора: {cpu} (средняя за минуту)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Всего: {memTotalBytes} / Использовано: {memUsageBytes}",
    "RAM info not available" : "RAM информация не доступна",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Всего: {swapTotalBytes} / Использовано: {swapUsageBytes}",
    "SWAP info not available" : "Информация о SWAP не доступна",
    "Not supported!" : "Не поддерживается!",
    "Press ⌘-C to copy." : "Нажмите ⌘-C для копирования. ",
    "Press Ctrl-C to copy." : "Нажмите Ctrl-C для копирования.",
    "System" : "Система",
    "Monitoring" : "Мониторинг",
    "Monitoring app with useful server information" : "Приложение мониторинга с полезной информацией о сервере",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Предоставляет полезную информацию о сервере, такую как загрузка процессора, использование ОЗУ, диска, количество пользователей и т.д.",
    "Operating System:" : "Операционная система:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Неизвестный процессор",
    "Memory:" : "память:",
    "Server time:" : "Серверное время:",
    "Uptime:" : "Время работы:",
    "Temperature" : "Температура",
    "Load" : "Нагрузка",
    "Memory" : "Память",
    "Disk" : "Диск",
    "Mount:" : "Метка диска:",
    "Filesystem:" : "Файловая система:",
    "Size:" : "Размер:",
    "Available:" : "Доступно:",
    "Used:" : "Используется:",
    "Files:" : "Файлы:",
    "Storages:" : "Хранилища:",
    "Free Space:" : "Свободно:",
    "Network" : "Сеть",
    "Hostname:" : "Хост:",
    "DNS:" : "DNS:",
    "Gateway:" : "Шлюз:",
    "Status:" : "Статус:",
    "Speed:" : "Скорость:",
    "Duplex:" : "Дуплекс:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Активные пользователи",
    "Total users:" : "Всего пользователей:",
    "24 hours:" : "24 часа:",
    "1 hour:" : "1 час:",
    "5 mins:" : "5 минут:",
    "Shares" : "Общие ресурсы",
    "Users:" : "Пользователей:",
    "Groups:" : "Группы:",
    "Links:" : "Ссылки:",
    "Emails:" : "Письма:",
    "Federated sent:" : "Отправлено в федерацию:",
    "Federated received:" : "Получено из федерации:",
    "Talk conversations:" : "Обсуждения:",
    "PHP" : "PHP",
    "Version:" : "Версия:",
    "Memory limit:" : "Лимит памяти:",
    "Max execution time:" : "Максимальное время выполнения:",
    "Upload max size:" : "Максимальный размер для отправки:",
    "OPcache Revalidate Frequency:" : "Частота повторной проверки OPcache:",
    "Extensions:" : "Расширения:",
    "Unable to list extensions" : "Невозможно перечислить расширения",
    "Show phpinfo" : "Показать информацию о php",
    "Database" : "База данных",
    "Type:" : "Тип:",
    "External monitoring tool" : "Внешний мониторинг",
    "You can connect an external monitoring tool by using this end point:" : "Вы можете подключить внешний мониторинг используя этот адрес:",
    "Copy" : "Копировать",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Если к строке URL добавить «?format=json», то ответ сервера будет в формате JSON.",
    "To use an access token, please generate one then set it using the following command:" : "Чтобы использовать токен доступа, пожалуйста, сгенерируйте его, а затем установите с помощью следующей команды:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Затем передайте токен с заголовком «NC-Token» при запросе указанного выше URL.",
    "You will get a notification once one of your disks is nearly full." : "Когда один из ваших дисков будет практически полностью заполнен, вы получите уведомление."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-27.1.7p0.tgz: nextcloud/apps/serverinfo/l10n/ru.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Информация о ЦП недоступна",
    "Load average: {cpu} (last minute)" : "Загрузка процессора: {cpu} (средняя за минуту)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Всего: {memTotalBytes} / Использовано: {memUsageBytes}",
    "RAM info not available" : "RAM информация не доступна",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Всего: {swapTotalBytes} / Использовано: {swapUsageBytes}",
    "SWAP info not available" : "Информация о SWAP не доступна",
    "Copied!" : "Скопировано!",
    "Not supported!" : "Не поддерживается!",
    "Press ⌘-C to copy." : "Нажмите ⌘-C для копирования. ",
    "Press Ctrl-C to copy." : "Нажмите Ctrl-C для копирования.",
    "System" : "Система",
    "Monitoring" : "Мониторинг",
    "Monitoring app with useful server information" : "Приложение мониторинга с полезной информацией о сервере",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Предоставляет полезную информацию о сервере, такую как загрузка процессора, использование ОЗУ, диска, количество пользователей и т.д.",
    "Operating System:" : "Операционная система:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Неизвестный процессор",
    "Memory:" : "память:",
    "Server time:" : "Серверное время:",
    "Uptime:" : "Время работы:",
    "Temperature" : "Температура",
    "Load" : "Нагрузка",
    "Memory" : "Память",
    "Disk" : "Диск",
    "Mount:" : "Метка диска:",
    "Filesystem:" : "Файловая система:",
    "Size:" : "Размер:",
    "Available:" : "Доступно:",
    "Used:" : "Используется:",
    "Files:" : "Файлы:",
    "Storages:" : "Хранилища:",
    "Free Space:" : "Свободно:",
    "Network" : "Сеть",
    "Hostname:" : "Хост:",
    "DNS:" : "DNS:",
    "Gateway:" : "Шлюз:",
    "Status:" : "Статус:",
    "Speed:" : "Скорость:",
    "Duplex:" : "Дуплекс:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Активные пользователи",
    "Total users:" : "Всего пользователей:",
    "24 hours:" : "24 часа:",
    "1 hour:" : "1 час:",
    "5 mins:" : "5 минут:",
    "Shares" : "Общие ресурсы",
    "Users:" : "Пользователей:",
    "Groups:" : "Группы:",
    "Links:" : "Ссылки:",
    "Emails:" : "Письма:",
    "Federated sent:" : "Отправлено в федерацию:",
    "Federated received:" : "Получено из федерации:",
    "Talk conversations:" : "Обсуждения:",
    "PHP" : "PHP",
    "Version:" : "Версия:",
    "Memory limit:" : "Лимит памяти:",
    "Max execution time:" : "Максимальное время выполнения:",
    "Upload max size:" : "Максимальный размер для отправки:",
    "OPcache Revalidate Frequency:" : "Частота повторной проверки OPcache:",
    "Extensions:" : "Расширения:",
    "Unable to list extensions" : "Невозможно перечислить расширения",
    "Show phpinfo" : "Показать информацию о php",
    "Database" : "База данных",
    "Type:" : "Тип:",
    "External monitoring tool" : "Внешний мониторинг",
    "Copy" : "Копировать",
    "To use an access token, please generate one then set it using the following command:" : "Чтобы использовать токен доступа, пожалуйста, сгенерируйте его, а затем установите с помощью следующей команды:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Затем передайте токен с заголовком «NC-Token» при запросе указанного выше URL."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
